summaryrefslogtreecommitdiffstats
path: root/libkdenetwork/libgpgme-copy/gpgme/wait-global.c
diff options
context:
space:
mode:
Diffstat (limited to 'libkdenetwork/libgpgme-copy/gpgme/wait-global.c')
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/wait-global.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/libkdenetwork/libgpgme-copy/gpgme/wait-global.c b/libkdenetwork/libgpgme-copy/gpgme/wait-global.c
index bfa618dd1..ba064ebbd 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/wait-global.c
+++ b/libkdenetwork/libgpgme-copy/gpgme/wait-global.c
@@ -41,7 +41,7 @@
GPGME_EVENT_START event. After that, it is added to the global
list of active contexts.
- The gpgme_wait function contains a select() loop over all file
+ The gpgme_wait function tqcontains a select() loop over all file
descriptors in all active contexts. If an error occurs, it closes
all fds in that context and moves the context to the global done
list. Likewise, if a context has removed all I/O callbacks, it is
@@ -75,15 +75,15 @@ struct ctx_list_item
gpgme_error_t status;
};
/* The active list contains all contexts that are in the global event
loop, have active I/O callbacks, and have already seen the start
event. */
static struct ctx_list_item *ctx_active_list;
/* The done list contains all contexts that have previously been
active but now are not active any longer, either because they
finished successfully or an I/O callback returned an error. The
- status field in the list item contains the error value (or 0 if
+ status field in the list item tqcontains the error value (or 0 if
successful). */
static struct ctx_list_item *ctx_done_list;
@@ -75,15 +75,15 @@ struct ctx_list_item
gpgme_error_t status;
};
-/* The active list contains all contexts that are in the global event
+/* The active list tqcontains all contexts that are in the global event
loop, have active I/O callbacks, and have already seen the start
event. */
@@ -75,15 +75,15 @@ struct ctx_list_item
event. */
static struct ctx_list_item *ctx_active_list;
-/* The done list contains all contexts that have previously been
+/* The done list tqcontains all contexts that have previously been
active but now are not active any longer, either because they
finished successfully or an I/O callback returned an error. The